<?php

// main Revolution Multimedia Gallery Wordpress Plugin plugin class
class FWDRMG{
	// constants
	const MIN_WP_VER =  "3.5.0";
	const CAPABILITY = "edit_fwdrmg";
	const VERSION = "2.0";
	
	// variables
	private $_data;
	private $_dir_url;
    
    private static $_rmg_id = 0;
    
    // constructor
    public function init(){
		$this->_dir_url = plugin_dir_url(dirname(__FILE__));
		
		// set data
		$this->_data = new FWDRMGData();		
		$this->_data->init();
		
    	// set hooks
    	add_action("admin_menu", array($this, "add_plugin_menu"));
		add_action("wp_enqueue_scripts", array($this, "add_header_files"));
		add_shortcode("fwdrmg", array($this, "set_rmgerflow"));
    }

    // functions
    public function add_plugin_menu(){
    	// add menus
        add_menu_page("Gallery Title", "Revolution Multimedia Gallery", FWDRMG::CAPABILITY, "FWDRMGMenu-General-Settings", array($this, "set_general_settings"), $this->_dir_url . "content/icons/menu-icon.png");
       	add_submenu_page("FWDRMGMenu-General-Settings", "General settings", "General settings", FWDRMG::CAPABILITY, "FWDRMGMenu-General-Settings");
       	add_submenu_page("FWDRMGMenu-General-Settings", "Galleries manager", "Galleries manager", FWDRMG::CAPABILITY, "FWDRMGMenu-Playlists-Manager", array($this, "set_playlists_manager"));
       	add_submenu_page("FWDRMGMenu-General-Settings", "CSS Editor", "CSS Editor", FWDRMG::CAPABILITY, "FWDRMGMenu-CSS-Editor", array($this, "set_css_editor"));
       	
       	// add meta boxes
       	$post_type_screens = array("post", "page");

    	foreach ($post_type_screens as $screen)
    	{
       		add_meta_box("fwdrmg-shortcode-generator", "Revolution Multimeda Gallery Shortcode Generator",  array($this, "set_custom_meta_box"), $screen, "side", "default");
    	}
    }
    
	private function check_wp_ver(){
	    global $wp_version;
	    
		$exit_msg = "The Revolution Multimedia Gallery requires WordPress " . FWDRMG::MIN_WP_VER . " or newer. <a href='http://codex.wordpress.org/Updating_WordPress'>Please update!</a>";
		
		if (version_compare($wp_version, FWDRMG::MIN_WP_VER) <= 0)
		{
			echo $exit_msg;
			
			return false;
		}
		
		return true;
	}

    public function set_general_settings(){
    	if (!$this->check_wp_ver()){
    		return;
    	}
    	
    	$msg = "";
    	
    	$set_id = 0;
		$set_order_id = 0;
		$tab_init_id = 0;
    	
	    if (!empty($_POST) && check_admin_referer("fwdrmg_general_settings_update", "fwdrmg_general_settings_nonce")){
			$data_obj = json_decode(str_replace("\\", "", $_POST["settings_data"]), true);
			
			$action = $data_obj["action"];
			$settingsAr = $data_obj["settings_ar"];

			// Sanitize input.
			foreach($settingsAr as $key => $value) {	
				
				if(!empty($settingsAr[$key]["name"])){
					$settingsAr[$key]["name"] = sanitize_text_field($settingsAr[$key]["name"]);
				}

				if(!empty($settingsAr[$key]["allGalleriesLabel"])){
					$settingsAr[$key]["allGalleriesLabel"] = sanitize_text_field($settingsAr[$key]["allGalleriesLabel"]);
				}

				if(!empty($settingsAr[$key]["slideShowDelay"])){
					$settingsAr[$key]["slideShowDelay"] = sanitize_text_field($settingsAr[$key]["slideShowDelay"]);
				}

				if(!empty($settingsAr[$key]["shareButtons"])){
					$settingsAr[$key]["shareButtons"] = sanitize_text_field($settingsAr[$key]["shareButtons"]);
				}

				if(!empty($settingsAr[$key]["shareText"])){
					$settingsAr[$key]["shareText"] = sanitize_text_field($settingsAr[$key]["shareText"]);
				}

				if(!empty($settingsAr[$key]["volume"])){
					$settingsAr[$key]["volume"] = sanitize_text_field($settingsAr[$key]["volume"]);
				}

				if(!empty($settingsAr[$key]["videoAutoPlayText"])){
					$settingsAr[$key]["videoAutoPlayText"] = sanitize_text_field($settingsAr[$key]["videoAutoPlayText"]);
				}
				
				if(!empty($settingsAr[$key]["logoPath"])){
					$settingsAr[$key]["logoPath"] = esc_url_raw($settingsAr[$key]["logoPath"]);
				}

				if(!empty($settingsAr[$key]["logoLink"])){
					$settingsAr[$key]["logoLink"] = esc_url_raw($settingsAr[$key]["logoLink"]);
				}

				if(!empty($settingsAr[$key]["thumbnailsPreviewWidth"])){
					$settingsAr[$key]["thumbnailsPreviewWidth"] = sanitize_text_field($settingsAr[$key]["thumbnailsPreviewWidth"]);
				}

				if(!empty($settingsAr[$key]["skipToVideoText"])){
					$settingsAr[$key]["skipToVideoText"] = sanitize_text_field($settingsAr[$key]["skipToVideoText"]);
				}

				if(!empty($settingsAr[$key]["skipToVideoButtonText"])){
					$settingsAr[$key]["skipToVideoButtonText"] = sanitize_text_field($settingsAr[$key]["skipToVideoButtonText"]);
				}
		
			}
			
			$this->_data->settings_ar = $settingsAr;
			$this->_data->set_data();
			
			switch ($action){
			    case "add":
			        $msg = "<div class='fwd-updated'><p style='padding:8px;'>Your new preset has been added!</p></div>";
			        $set_id = $data_obj["set_id"];
					$set_order_id = $data_obj["set_order_id"];
					$tab_init_id = $data_obj["tab_init_id"];
			        break;
			    case "save":
			        $msg = "<div class='fwd-updated'><p style='padding:8px;'>Your preset settings have been updated!</p></div>";
			        $set_id = $data_obj["set_id"];
					$set_order_id = $data_obj["set_order_id"];
					$tab_init_id = $data_obj["tab_init_id"];
			        break;
			    case "del":
			       	$msg = "<div class='fwd-updated'><p style='padding:8px;'>Your preset has been deleted!</p></div>";
			        break;
			}
		}
		
		// jquery ui
		wp_enqueue_style("fwdrmg_fwd_ui_css", $this->_dir_url . "css/fwd_ui.css", array(), '1.10.4');
		wp_enqueue_script("fwdrmg_fwdtooltip", $this->_dir_url . "js/fwdtooltip.js", array(), '1.0');
		wp_enqueue_script("jquery-ui-tabs");
		wp_enqueue_script("jquery-ui-sortable");
		wp_enqueue_script("jquery-ui-accordion");
		
		// spectrum colorpicker
    	wp_enqueue_style("fwdrmg_spectrum_css", $this->_dir_url . "css/spectrum.css");
    	wp_enqueue_script("fwdrmg_spectrum_script", $this->_dir_url . "js/spectrum.js");
    	
    	// general settings script
		wp_enqueue_media();
        wp_enqueue_script("fwdrmg_general_settings_script", $this->_dir_url . "js/general_settings.js");
		
    	include_once "general_settings.php";
    }
    
 	public function set_playlists_manager(){
    	if (!$this->check_wp_ver()){
    		return;
    	}
    	
    	$msg = "";
    	
	    if (!empty($_POST) && check_admin_referer("fwdrmg_playlist_manager_update", "fwdrmg_playlist_manager_nonce")){
			$mainPlaylistsAr = json_decode(str_replace("\\", "", $_POST["playlist_data"]), true);

			foreach($mainPlaylistsAr as &$mainPlaylist){
				 
				$mainPlaylist["name"] = sanitize_text_field($mainPlaylist["name"]);
				
				foreach($mainPlaylist['categories'] as &$gallery){
					if(!empty($gallery['name'])){
						$gallery['name'] = sanitize_text_field($gallery['name']);
					}
					
					foreach($gallery['thumbs'] as &$thb){

						if(!empty($thb['name'])){
							$thb['name'] = sanitize_text_field($thb['name']);
						}

						if(!empty($thb['path'])){
							$thb['path'] = esc_url_raw($thb['path']);
						}
						
						/*if(!empty($thb['url'])){
							$thb['url'] = esc_url_raw($thb['url']);
						}*/

						if(!empty($thb['item_max_width'])){
							$thb['item_max_width'] = sanitize_text_field($thb['item_max_width']);
						}

						if(!empty($thb['item_max_height'])){
							$thb['item_max_height'] = sanitize_text_field($thb['item_max_height']);
						}
						
						if(!empty($thb['video_poster_source'])){
							$thb['video_poster_source'] = esc_url_raw($thb['video_poster_source']);
						}

						if(!empty($thb['subtitle'])){
							$thb['subtitle'] = esc_url_raw($thb['subtitle']);
						}

						/*if(!empty($thb['thumbnailsPreview'])){
							$thb['thumbnailsPreview'] = esc_url_raw($thb['thumbnailsPreview']);
						}*/

						if(!empty($thb['vast'])){
							$thb['vast'] = esc_url_raw($thb['vast']);
						}

						if(!empty($thb['pass'])){
							$thb['pass'] = sanitize_text_field($thb['pass']);
						}
						
					}
				}
			}
			
			$this->_data->playlists_ar = $mainPlaylistsAr;
			$this->_data->set_data();
			
			$msg = "<div class='fwd-updated'><p style='padding:8px;'>Your playlists have been updated!</p></div>";
		}
		
		// jquery ui
		wp_enqueue_style("fwdrmg_fwd_ui_css", $this->_dir_url . "css/fwd_ui.css", array(), '1.10.4');
		wp_enqueue_script("fwdrmg_fwdtooltip", $this->_dir_url . "js/fwdtooltip.js", array(), '1.0');
		wp_enqueue_script("jquery-ui-tabs");
		wp_enqueue_script("jquery-ui-sortable");
		wp_enqueue_script("jquery-ui-accordion");
		wp_enqueue_script("jquery-ui-dialog");

		
		// playlist manager script
		wp_enqueue_media();
        wp_enqueue_script("fwdrmg_playlist_manager_script", $this->_dir_url . "js/playlist_manager.js");
        
    	include_once "playlist_manager.php";
    }
    
    public function set_css_editor(){
    	if (!$this->check_wp_ver()){
    		return;
    	}
    	
    	$msg = "";
    	$scroll_pos = 0;
    	
    	$css_file = plugin_dir_path(dirname(__FILE__)) . "css/fwdrmg.css";
    	
	    if (!empty($_POST) && check_admin_referer("fwdrmg_css_editor_update", "fwdrmg_css_editor_nonce")){
			$handle = fopen($css_file, "w") or die("Cannot open file: " . $css_file);
			
			$data = str_replace("\\", "", $_POST["css_data"]);
			$data = str_replace("'e", "'\\e", $data);
			$scroll_pos = $_POST["scroll_pos"];
			
			fwrite($handle, $data);
			
			$msg = "<div class='fwd-updated'><p style='padding:8px;'>The CSS file has been updated!</p></div>";
		}
		
		wp_enqueue_style("fwdrmg_fwd_ui_css", $this->_dir_url . "css/fwd_ui.css");
	  			
		$handle = fopen($css_file, "r") or die("Cannot open file: " . $css_file);
        
    	include_once "css_editor.php";
    	
    	fclose($handle);
    }
    
	public static function set_action_links($links){
		$settings_link = "<a href='" . get_admin_url(null, "admin.php?page=FWDRMGMenu-General-Settings") . "'>Settings</a>";
   		array_unshift($links, $settings_link);
   		
   		return $links;
	}
	
 	public function add_header_files(){
    	wp_enqueue_style("fwdrmg_rmg_css", $this->_dir_url . "css/fwdrmg.css");
    	wp_enqueue_script("fwdrmg_rmg_script", $this->_dir_url . "js/FWDRMG.js");
    }
    
    public function get_constructor($preset, $pid){
    
    	// Prepare share buttons.
		$shareButtons = preg_replace('/\s+/', '',$preset['shareButtons']);
		$shareLength = strlen($shareButtons);
		$shareButtons = explode(",", $shareButtons);

		$shareButtonsF = '';
		foreach($shareButtons as $key => $value) {
			$shareButtonsF .= "'" . $value . "',";
		}
		$shareButtonsF = mb_substr($shareButtonsF, 0, -1);
		if($shareLength < 2){
			$shareButtonsF = '';
		}

    	$constructor =  "FWDRMGUtils.onReady(function(){new FWDRMG({mainFolderPath:'" . $this->_dir_url . "content'" . ",useDeepLinking:" . ($preset['useDeepLinking']  == 'true' ? 'true' : 'false') . ",displayType:'" . $preset['displayType'] . "',rightClickContextMenu:'" . $preset['rightClickContextMenu'] .  "',useVectorIcons:" . ($preset['useVectorIcons'] == 'true' ? 'true' : 'false') .  ",autoScale:" . ($preset['autoScale'] == 'true' ? 'true' : 'false') . ",parentId:'fwdrmgDiv" . FWDRMG::$_rmg_id. "',instanceName:'rmg" . FWDRMG::$_rmg_id . "',galleryId:'fwdrmgPlaylist" . $pid . "',randomizeGalleries:" . ($preset['randomizeGalleries'] == 'true' ? 'true' : 'false') .  ",showAllGalleries:" . ($preset['showAllGalleries'] == 'true' ? 'true' : 'false') . ",buttonsAlignment:'" . $preset['buttonsAlignment'] . "',maxWidth:" . $preset['maxWidth'] . ",maxHeight:" . $preset['maxHeight'] . ",minHeight:" . $preset['minHeight'] . ",zIndex:" . $preset['zIndex'] . ",startAtGallery:" . $preset['startAtGallery'] . ",startAtItem:" . $preset['startAtItem'] . ",mediaLazyLoading:" . ($preset['mediaLazyLoading']  == 'true' ? 'true' : 'false') . ",useDrag:" . ($preset['useDrag']  == 'true' ? 'true' : 'false') . ",showSlideShowButton:" . ($preset['showSlideShowButton']  == 'true' ? 'true' : 'false') . ",showSlideShowAnimation:" . ($preset['showSlideShowAnimation']  == 'true' ? 'true' : 'false') . ",slideShowAutoPlay:" . ($preset['slideShowAutoPlay']  == 'true' ? 'true' : 'false') . ",slideShowAutoStop:" . ($preset['slideShowAutoStop']  == 'true' ? 'true' : 'false') . ",slideShowDelay:" . $preset['slideShowDelay'] . ",slideShowBkColor:'" . $preset['slideShowBkColor'] . "',slideShowFillColor:'" . $preset['slideShowFillColor'] . "',useKeyboard:" . ($preset['useKeyboard'] == 'true'  ? 'true' : 'false') . ",useDoubleClick:" . ($preset['useDoubleClick']  == 'true' ? 'true' : 'false') . ",showMenuButton:" . ($preset['showMenuButton']  == 'true' ? 'true' : 'false') . ",allGalleriesLabel:'" . $preset['allGalleriesLabel'] . "',menuBackgroundColor:'" . $preset['menuBackgroundColor'] . "',showFullscreenButton:" . ($preset['showFullscreenButton']  == 'true' ? 'true' : 'false') . ",showZoomButton:" . ($preset['showZoomButton'] == 'true' ? 'true' : 'false') . ",showCounter:" . ($preset['showCounter'] == 'true' ? 'true' : 'false') . ",showNextAndPrevBtns:" . ($preset['showNextAndPrevBtns']  == 'true' ? 'true' : 'false') . ",hideButtonsOnDrag:" . ($preset['hideButtonsOnDrag']  == 'true' ? 'true' : 'false') . ",maxZoom:" . $preset['maxZoom'] . ",buttonsHideDelay:" . $preset['buttonsHideDelay'] . ",defaultItemWidth:" . $preset['defaultItemWidth'] . ",defaultItemHeight:" . $preset['defaultItemHeight'] . ",itemOffsetHeightButtonsTop:" . $preset['itemOffsetHeightButtonsTop'] . ",spaceBetweenBtns:" . $preset['spaceBetweenBtns'] . ",buttonsOffsetIn:" . $preset['buttonsOffsetIn'] . ",buttonsOffsetOut:" . $preset['buttonsOffsetOut'] . ",itemBorderSize:" . $preset['itemBorderSize'] . ",itemBackgroundColor:'" . $preset['itemBackgroundColor'] . "',itemBorderColor:'" . $preset['itemBorderColor'] . "',preloaderBkColor:'" . $preset['preloaderBkColor'] . "',preloaderFillColor:'" . $preset['preloaderFillColor'] . "',backgroundColor:'" . $preset['backgroundColor'] . "',shareButtons:[" . $shareButtonsF . "],shareText:'" . $preset['shareText'] . "',sharedURL:'" . $preset['sharedURL'] . "',shareMainBackgroundColor:'" . $preset['shareMainBackgroundColor'] . "',shareBackgroundColor:'" . $preset['shareBackgroundColor'] . "',showThumbnails:" . ($preset['showThumbnails']  == 'true' ? 'true' : 'false') . ",showThumbnailsIcon:" . ($preset['showThumbnailsIcon'] == 'true' ? 'true' : 'false') . ",thumbnailsHeight:" . $preset['thumbnailsHeight'] . ",thumbnailsOverlayColor:'" . $preset['thumbnailsOverlayColor'] . "',thumbnailsBorderSize:" . $preset['thumbnailsBorderSize'] . ",thumbnailsBorderColor:'" . $preset['thumbnailsBorderColor'] . "',spaceBetweenThumbnailsAndItem:" . $preset['spaceBetweenThumbnailsAndItem'] . ",spaceBetweenThumbnails:" . $preset['spaceBetweenThumbnails'] . ",caption:" . ($preset['caption'] == 'true' ? 'true' : 'false') . ",captionPosition:'" . $preset['captionPosition'] . "',showCaptionOnSmallScreens:" . ($preset['showCaptionOnSmallScreens'] == 'true' ? 'true' : 'false') . ",animateCaption:" . ($preset['animateCaption'] == 'true' ? 'true' : 'false') . ",captionAnimationType:'" . $preset['captionAnimationType'] . "',useVideo:" . ($preset['useVideo'] == 'true' ? 'true' : 'false') . ",fillEntireScreenWithPoster:" . ($preset['fillEntireScreenWithPoster'] == 'true' ? 'true' : 'false') . ",volume:" . $preset['volume'] . ",videoAutoPlay:" . ($preset['videoAutoPlay'] == 'true' ? 'true' : 'false') . ",nextVideoAutoPlay:" . ($preset['nextVideoAutoPlay'] == 'true' ? 'true' : 'false') . ",videoAutoPlayText:'" . $preset['videoAutoPlayText'] . "',showLogo:" . ($preset['showLogo'] == 'true' ? 'true' : 'false') . ",logoPath:'" . $preset['logoPath'] . "',logoLink:'" . $preset['logoLink'] . "',showControllerWhenVideoIsStopped:" . ($preset['showControllerWhenVideoIsStopped'] == 'true' ? 'true' : 'false') . ",showDefaultControllerForVimeo:" . ($preset['showDefaultControllerForVimeo'] == 'true' ? 'true' : 'false') . ",showScrubberWhenControllerIsHidden:" . ($preset['showScrubberWhenControllerIsHidden'] == 'true' ? 'true' : 'false') . ",showRewindButton:" . ($preset['showRewindButton'] == 'true' ? 'true' : 'false') . ",showVolumeButton:" . ($preset['showVolumeButton'] == 'true' ? 'true' : 'false') . ",showTime:" . ($preset['showTime'] == 'true' ? 'true' : 'false') . ",timeColor:'" . $preset['timeColor'] . "',showChromecastButton:" . ($preset['showChromecastButton'] == 'true' ? 'true' : 'false') . ",showPlaybackRateButton:" . ($preset['showPlaybackRateButton'] == 'true' ? 'true' : 'false') . ",showQualityButton:" . ($preset['showQualityButton'] == 'true' ? 'true' : 'false') . ",showFullScreenButton:" . ($preset['showFullScreenButton'] == 'true'? 'true' : 'false') . ",showScrubberToolTipLabel:" . ($preset['showScrubberToolTipLabel'] == 'true' ? 'true' : 'false') . ",youtubeQualityButtonNormalColor:'" . $preset['youtubeQualityButtonNormalColor'] . "',youtubeQualityButtonSelectedColor:'" . $preset['youtubeQualityButtonSelectedColor'] . "',scrubbersToolTipLabelBackgroundColor:'" . $preset['scrubbersToolTipLabelBackgroundColor'] . "',scrubbersToolTipLabelFontColor:'" . $preset['scrubbersToolTipLabelFontColor'] . "',audioVisualizerLinesColor:'" . $preset['audioVisualizerLinesColor'] . "',audioVisualizerCircleColor:'" . $preset['audioVisualizerCircleColor'] . "',thumbnailsPreviewWidth:" . $preset['thumbnailsPreviewWidth'] . ",thumbnailsPreviewBackgroundColor:'" . $preset['thumbnailsPreviewBackgroundColor'] . "',thumbnailsPreviewLabelBackgroundColor:'" . $preset['thumbnailsPreviewLabelBackgroundColor'] . "',thumbnailsPreviewLabelFontColor:'" . $preset['thumbnailsPreviewLabelFontColor'] . "',skipToVideoText:'" . $preset['skipToVideoText'] . "',skipToVideoButtonText:'" . $preset['skipToVideoButtonText'] . "'});});";
    	return $constructor;
    }
    
    public function get_playlist($playlist, $pid){
    	
    	$playlist_str = "<div id='fwdrmgPlaylist$pid' style='display: none;'>";
    	
    	foreach ($playlist["categories"] as $category){
    		$playlist_str .= "<ul data-category-name='" . $category["name"] . "'>";
    		
    		foreach ($category["thumbs"] as $thumb){
			
				$playlist_str .= "<li data-src='" . $thumb["url"] . "'";
					
				if(isset($thumb["path"]) && strlen($thumb["path"]) >= 1){
					$playlist_str .= " data-thumb='" . $thumb["path"] . "'";
				}
				
				if(isset($thumb["video_poster_source"]) && strlen($thumb["video_poster_source"]) >= 1){
					$playlist_str .= " data-poster='" . $thumb["video_poster_source"] . "'";
				}
				
				if(isset($thumb["item_max_width"]) && strlen($thumb["item_max_width"]) >= 1){
					$playlist_str .= " data-width='" . $thumb["item_max_width"] . "'";
				}
				
				if(isset($thumb["item_max_height"]) && strlen($thumb["item_max_height"]) >= 1){
					$playlist_str .= " data-height='" . $thumb["item_max_height"] . "'";
				}

				if(isset($thumb["subtitle"]) && strlen($thumb["subtitle"]) >= 1){
					$playlist_str .= " data-subtitle='" . $thumb["subtitle"] . "'";
				}

				if(isset($thumb["thumbnailsPreview"]) && strlen($thumb["thumbnailsPreview"]) >= 1){
					$playlist_str .= " data-thumbnails-preview='" . $thumb["thumbnailsPreview"] . "'";
				}
				
				if(isset($thumb["vast"]) && strlen($thumb["vast"]) >= 1){
					$playlist_str .= " data-vast='" . $thumb["vast"] . "'";
				}

				if(isset($thumb["pass"]) && strlen($thumb["pass"]) >= 1){
					$playlist_str .= " data-password='" . md5($thumb["pass"]) . "'";
				}

				$playlist_str .= ">";
					
				if(isset($thumb["info"]) && strlen($thumb["info"]) >= 3){
					$playlist_str .= "<div>" . $thumb["info"] . "</div>";
				}
				
			
				$playlist_str .= "</li>";
				 
    		}
    	
    		$playlist_str .= "</ul>";
    	}
    	
    	$playlist_str .= "</div>";
    	
    	return $playlist_str;
    }
    
 	public function set_rmgerflow($atts){
		extract(shortcode_atts(array("preset_id" => 0, "playlist_id" => 0), $atts, "fwdrmg"));


		// Preset.
		$preset = NULL;
    	foreach ($this->_data->settings_ar as $set){
    		if ($set["name"] == $preset_id){
    			$preset = $set;
    		}
    	}
    	
    	if (is_null($preset)){
    		return "Preset with id ". $preset_id . " does not exist!";
    	}
    	
    	// Playlist.
    	$playlist = NULL;
    	foreach ($this->_data->playlists_ar as $pl){
    		if ($pl["name"] == $playlist_id){
    			$playlist = $pl;
    		}
    	}
    	 	
    	if (is_null($playlist)){
    		return "Playlist with id ". $playlist_id . " does not exist!";
    	}
		
		// Output data.
		$cov_constructor = $this->get_constructor($preset, $playlist_id);
		$cov_div = "<div id='fwdrmgDiv" . FWDRMG::$_rmg_id. "'></div>";
		$cov_playlist = $this->get_playlist($playlist, $playlist_id);
		
		FWDRMG::$_rmg_id++;
		$cov_output = $cov_div . $cov_playlist;

		wp_register_script( 'fwdrmg-dummy-handle-footer', '', [], '', true );
   		wp_enqueue_script( 'fwdrmg-dummy-handle-footer'  );
    	wp_add_inline_script( 'fwdrmg-dummy-handle-footer', $cov_constructor );
		
		return $cov_output;
	}
	
	public function set_custom_meta_box($post){
		if (!$this->check_wp_ver())
    	{
    		return;
    	}
		
		// presets
		$presetsNames = array();
		
		foreach ($this->_data->settings_ar as $setting)
    	{
    		$el = array(
    						"id" => $setting["id"],
    						"name" => $setting["name"]
    				   );
    				   
    		array_push($presetsNames, $el);
    	}
    	
		// playlists
		$playlistsNames = array();
		
		if (isset($this->_data->playlists_ar))
		{
			foreach ($this->_data->playlists_ar as $playlist)
	    	{
	    		$el = array(
	    						"id" => $playlist["id"],
	    						"name" => $playlist["name"]
	    				   );
	    				   
	    		array_push($playlistsNames, $el);
	    	}
		}
		
    	wp_enqueue_style("fwdrmg_fwd_ui_css", $this->_dir_url . "css/fwd_ui.css");
		wp_enqueue_script("fwdrmg_shortcode_script", $this->_dir_url . "js/shortcode.js");
		
    	include_once "meta_box.php";
	}
}

?>